@@ -28,11 +28,11 @@ from .floor import floor
 from .exp import exp
 from .factorial import factorial
 from .integrate import integrate
-from .limit import limit
 from .ln import ln
 from .log import log
 from .radians import radians
 from .degrees import degrees
 from .cbrt import cbrt
 from .cubic import cubic
+from .quartic import quartic
 from .constants import *
\ No newline at end of file
