@@ -7,10 +7,9 @@ def factorial(x):
                 raise ValueError("Factorial of a negative integer is undefined.")
             else:
                 ans = 1
-                for i in range(1,x+1):
+                for i in range(1,int(x)+1):
                     ans *= i
                 return ans
-    else:
-        def integrand(t):
-            return t**x * exp(-t)
-        return integrate(integrand, 0, 100)
+    def integrand(t):
+        return t**x * exp(-t)
+    return integrate(integrand, 0, 100)
\ No newline at end of file
